Demo of Angular Local Storage Module
Author: Gregory Pike

# Give it a try

> {{storageType}} value

The Angular Local Storage Module is meant to be a plug-and-play Angular module for accessing the browsers Local Storage API.

Angular Local Storage offers you access to the browser local storage API through Angular but also allows has the following features:

- Control local storage access through key prefices (e.g. "myApp.keyName")
- Checks browser support and falls back to cookies for antiquated browsers
- Allows programmatic access to remove all keys for a given app

### Usage

###### Dependencies:

- `AngularJS` http://angularjs.org/
- `Angular Local Storage Module` angular-local-storage.js

###### JS Example

    var YourCtrl = function($scope, localStorageService, ...) {
      // To add to local storage
      localStorageService.set('localStorageKey','Add this!');
      // Read that value back
      var value = localStorageService.get('localStorageKey');
      // To remove a local storage
      localStorageService.remove('localStorageKey');
      // Removes all local storage
      localStorageService.clearAll();
      // You can also play with cookies the same way
      localStorageService.cookie.set('localStorageKey','I am a cookie value now');
    }

### API Access

Call | Arguments | Action | Returns
--- | --- | --- | ---
`isSupported` | n/a | Checks the browsers support for local storage | Boolean for success
`set` | key, value | Adds a key-value pair to the browser local storage | Boolean for success
`get` | key | Gets a value from local storage | Stored value
`remove` | key, ... | Removes a key-value pairs from the browser local storage | n/a
`clearAll` | n/a | Warning Removes all local storage key-value pairs for this app. It will optionally take a string, which is converted to a regular expression, and then clears keys based on that regular expression. | Boolean for success
`cookie` | set | get | remove | clearAll | Each function within cookie uses the same arguments as the coresponding local storage functions | n/a